@@ -29,7 +29,7 @@
 static PangoEngineRange basic_ranges[] = {
   /* Language characters */
   { 0x0380, 0x058f, "*" },
-  { 0x0591, 0x05f4, "*" }, /* Hebrew */
+  { 0x0591, 0x05f4, "" }, /* Hebrew */
   { 0x060c, 0x06f9, "" }, /* Arabic */
   { 0x0e01, 0x0e5b, "" },  /* Thai */
   { 0x10a0, 0x10ff, "*" }, /* Georgian */
